| Feature | Description |
| --- | --- |
| **Name** | `en_john_ner` |
| **Version** | `0.0.0` |
| **spaCy** | `>=3.5.4,<3.6.0` |
| **Default Pipeline** | `ner` |
| **Components** | `ner` |
| **Vectors** | 0 keys, 0 unique vectors (0 dimensions) |
| **Sources** | n/a |
| **License** | n/a |
| **Author** | [n/a]() |

### Label Scheme

<details>

<summary>View label scheme (13 labels for 1 components)</summary>

| Component | Labels |
| --- | --- |
| **`ner`** | `DATE`, `EDUC`, `EMAIL`, `LANG`, `NAT`, `ORG`, `PERSON`, `POSITION`, `SCHOOL`, `SKILL`, `SPECIAL`, `TECH`, `TELEPHONE` |

</details>

### Accuracy

| Type | Score |
| --- | --- |
| `ENTS_F` | 79.40 |
| `ENTS_P` | 81.86 |
| `ENTS_R` | 77.09 |
| `NER_LOSS` | 823637.17 |